@@ -117,28 +117,34 @@ class Graph(object):
             params_header += str(key) + "=" + str(value) + " "
         return params_header
 
-    def query(self, q, params=None):
+    def query(self, q, params=None, timeout=None):
         """
         Executes a query against the graph.
         """
         if params is not None:
             q = self.build_params_header(params) + q
 
-        statistics = None
-        result_set = None
-
-        response = self.redis_con.execute_command("GRAPH.QUERY", self.name, q, "--compact")
+        command = ["GRAPH.QUERY", self.name, q, "--compact"]
+        if timeout:
+            if not isinstance(timeout, int):
+                raise Exception("Timeout argument must be a positive integer")
+            command += ["timeout", timeout]
+        response = self.redis_con.execute_command(*command)
         return QueryResult(self, response)
 
     def _execution_plan_to_string(self, plan):
-        return b"\n".join(plan)
+        return "\n".join(plan)
 
-    def execution_plan(self, query):
+    def execution_plan(self, query, params=None):
         """
         Get the execution plan for given query,
         GRAPH.EXPLAIN returns an array of operations.
         """
-        plan = self.redis_con.execute_command("GRAPH.EXPLAIN", self.name, query)
+        
+        if params is not None:
+            query = self.build_params_header(params) + query
+        
+        plan = self.redis_con.execute_command("GRAPH.EXPLAIN", self.name, query, query)
         return self._execution_plan_to_string(plan)
 
     def delete(self):
